# Guidelines for annotating regulation and regulatory processes in GO-CAM

Molecular functions, and the biological processes of which they are a part, are often subject to some form of regulation, typically in response to changing environmental conditions or stimuli.

In GO, regulation has a very specific meaning: for one molecular function to regulate another, the **mechanism must be known**, it must occur under **specific** **conditions**  (i.e. not constant), and may be **direct** (contiguous activities) or **indirect** (non-contiguous, with intervening activities). Regulatory activities may also have a **positive or negative effect** on the downstream activity.

Examples of regulatory molecular functions include, but are certainly not limited to, protein kinase activity, GTPase activator (GAP) activity, and transcription regulator activities.

Modeling regulation is an important aspect of GO-CAM curation but can differ according to how the regulatory activities function in the broader context of the biological process.

Examples of distinct ways to capture regulation in GO-CAMs are discussed below.

## Metabolic pathways and feedback regulatory mechanisms

Feedback mechanisms in which a product, or output, of one activity in a process inhibits another activity in a process (i.e. negative feedback loop) is an important way to regulate metabolic processes.

Feedback loops represent a type of process regulation that is ‘self-contained’, i.e. the regulatory activity is not typically part of another, larger regulatory process.

In these cases, curators include the regulatory activity in the metabolic model and capture the output molecules that stimulate the regulation and the causal relation between the regulatory and regulated activities.

An example of this type of regulation is found in the GDP-mannose biosynthetic process ([GO:0009298](https://amigo.geneontology.org/amigo/term/GO%3A0009298)), in which the terminal output generated by GMPPB, GDP-alpha-D-mannose, binds to, and stimulates the inhibitory activity of, GMPPA on GMPPB.

Figure 1 shows a cartoon schematic of how GMPPA inhibits GMPPB, while Figure 2 shows how this regulation is modeled in GO-CAM as part of the larger metabolic process. for *D. melanogaster* model for [GDP-mannose biosynthetic process from glucose (Dmel)](http://noctua.geneontology.org/workbench/noctua-visual-pathway-editor/?model_id=gomodel%3A662af8fa00000838).

In this model, the output, GDP-alpha-D-mannose, of the terminal activity in the pathway, mannose-1-phosphate guanylyltransferase (GTP) activity enabled by Gmppb, is a small molecule activator of the enzyme inhibitor activity enabled by Gmppa. When bound to GDP-alpha-D-mannose (2-), Gmppa undergoes a conformational change that then inhibits catalytic activity of Gmppb.

![](data:image/png;base64...)

https://www.nature.com/articles/s41594-021-00591-9

![](data:image/png;base64...)
